  /*  prefs.c - powershell
   *  Copyright (C) 1999  Matt Spong <spong@glue.umd.edu>
   *  Based from zterm.c by Michael Zucci from the libzvt docs
   *
   *  A big, puffy lotsa-shells-in-one app. 
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License
   *  along with this program; if not, write to the Free Software
   *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "powershell.h"

ZvtTerm * current_term;

preferences Prefs;

GtkWidget * pbox;
GtkWidget * widget, * widget2;

GtkWidget * dialog;
GtkWidget * hbox1, *hbox2, * vbox1, * vbox2, * vbox3, * vbox4, * vbox5;
GtkWidget * label1, * label2, * label3, * label4, * label5;
GtkWidget * label6;
GtkWidget * http_handler, * ftp_handler, * mail_handler, * telnet_handler, * bg_pixmap;
GtkWidget * use_pixmap, * transparent, * shaded;
GtkWidget * browse_button;

GtkFileSelection * f;

static void property_changed (GtkWidget * w, gpointer user_data)
{
  gnome_property_box_changed (GNOME_PROPERTY_BOX(pbox));
}

static void property_apply (GnomePropertyBox *box, int page_num,
			    gpointer data)
{

  if (page_num!=-1)
    return;

  

#ifdef ZVT_USE_MATCHING
  
  strcpy (Prefs.http_handler, gtk_entry_get_text (GTK_ENTRY(http_handler)));
  strcpy (Prefs.ftp_handler, gtk_entry_get_text (GTK_ENTRY(ftp_handler)));
  strcpy (Prefs.mail_handler, gtk_entry_get_text (GTK_ENTRY(mail_handler)));
  strcpy (Prefs.telnet_handler, gtk_entry_get_text (GTK_ENTRY(telnet_handler)));
#endif
  
  Prefs.use_pixmap = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(use_pixmap));
  Prefs.transparent = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(transparent));
  Prefs.shaded = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(shaded));
  
  strcpy (Prefs.bg_pixmap, gtk_entry_get_text (GTK_ENTRY(bg_pixmap)));
  
  WriteRCFile();
  UpdateAllTerms();
 
}



int DoPreferences ()
{
  pbox = gnome_property_box_new ();
  gtk_signal_connect (GTK_OBJECT(pbox), "apply",
		      GTK_SIGNAL_FUNC(property_apply), NULL);
  widget = gtk_vbox_new (TRUE, 0);

  CreatePrefs (widget);
  gnome_property_box_append_page (GNOME_PROPERTY_BOX(pbox),
				  widget,
				  gtk_label_new ("Appearance"));

#ifdef ZVT_USE_MATCHING
  widget2 = gtk_vbox_new (TRUE, 0);
  CreatePrefs2 (widget2);
  gnome_property_box_append_page (GNOME_PROPERTY_BOX(pbox),
				  widget2,
				  gtk_label_new ("Handlers"));
#endif

  gtk_widget_show_all (pbox);
}


void store_filename (GtkFileSelection * b, gpointer user_data)
{
  gchar * filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION(f));
  gtk_entry_set_text (GTK_ENTRY(bg_pixmap), filename);
}

void browse_clicked (GtkButton * button, gpointer data)
{
   
  f = GTK_FILE_SELECTION(gtk_file_selection_new ("Choose a Pixmap"));
  
  gtk_signal_connect (GTK_OBJECT(GTK_FILE_SELECTION(f)->ok_button),
	 	      "clicked", GTK_SIGNAL_FUNC (store_filename), NULL);
  
  gtk_signal_connect_object (GTK_OBJECT(GTK_FILE_SELECTION(f)->cancel_button),
			     "clicked", GTK_SIGNAL_FUNC (gtk_widget_destroy),
			     (gpointer) f);
  
  gtk_signal_connect_object (GTK_OBJECT(GTK_FILE_SELECTION(f)->ok_button),
			     "clicked", GTK_SIGNAL_FUNC (gtk_widget_destroy),
			     (gpointer) f);

  gtk_widget_show (GTK_WIDGET(f)); 
} 

int CreatePrefs2 (GtkContainer * area)
{
  gtk_box_pack_start (GTK_BOX(area), hbox1, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(hbox1), GTK_WIDGET(vbox1), TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(hbox1), vbox2, TRUE, TRUE, 0);


  label1 = gtk_label_new ("HTTP Handler");
  label2 = gtk_label_new ("FTP Handler");
  label3 = gtk_label_new ("Mail Handler");
  label4 = gtk_label_new ("Telnet Handler");
  
  http_handler = gtk_entry_new ();
  ftp_handler = gtk_entry_new ();
  mail_handler = gtk_entry_new ();
  telnet_handler = gtk_entry_new ();


  gtk_box_pack_start (GTK_BOX(vbox1), label1, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(vbox1), label2, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(vbox1), label3, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(vbox1), label4, TRUE, TRUE, 0);
  
  gtk_box_pack_start (GTK_BOX(vbox2), http_handler, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(vbox2), ftp_handler, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(vbox2), mail_handler, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(vbox2), telnet_handler, TRUE, TRUE, 0);

  gtk_entry_set_text (GTK_ENTRY(http_handler), Prefs.http_handler);
  gtk_entry_set_text (GTK_ENTRY(ftp_handler), Prefs.ftp_handler);
  gtk_entry_set_text (GTK_ENTRY(mail_handler), Prefs.mail_handler);
  gtk_entry_set_text (GTK_ENTRY(telnet_handler), Prefs.telnet_handler);


  gtk_signal_connect_object (GTK_OBJECT(http_handler), "changed", GTK_SIGNAL_FUNC(property_changed), GTK_OBJECT(area));
  gtk_signal_connect_object (GTK_OBJECT(ftp_handler), "changed", GTK_SIGNAL_FUNC(property_changed), GTK_OBJECT(area));
  gtk_signal_connect_object (GTK_OBJECT(mail_handler), "changed", GTK_SIGNAL_FUNC(property_changed), GTK_OBJECT(area));
  gtk_signal_connect_object (GTK_OBJECT(telnet_handler), "changed", GTK_SIGNAL_FUNC(property_changed), GTK_OBJECT(area));

}

int CreatePrefs (GtkContainer * area)
{
  
  hbox1 = gtk_hbox_new (TRUE, 1);
  vbox1 = gtk_vbox_new (TRUE, 1);
  vbox2 = gtk_vbox_new (TRUE, 1);
  vbox3 = gtk_vbox_new (TRUE, 1);
  hbox2 = gtk_hbox_new (TRUE, 1);
  vbox4 = gtk_vbox_new (TRUE, 1);
  vbox5 = gtk_vbox_new (TRUE, 1);

  label5 = gtk_label_new ("Background Pixmap");

  bg_pixmap = gtk_entry_new();
  use_pixmap = gtk_check_button_new_with_label ("Use Background Pixmap");
  transparent = gtk_check_button_new_with_label ("Transparent");
  shaded = gtk_check_button_new_with_label ("Shaded");

  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(use_pixmap), Prefs.use_pixmap);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(transparent), Prefs.transparent);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(shaded), Prefs.shaded);

  gtk_entry_set_text (GTK_ENTRY(bg_pixmap), Prefs.bg_pixmap);

  gtk_box_pack_start (GTK_BOX(area), vbox4, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(vbox4), vbox5, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(vbox5), transparent, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(vbox5), shaded, TRUE, TRUE, 0);

  gtk_box_pack_start (GTK_BOX(vbox4), use_pixmap, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(vbox4), hbox2, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(hbox2), label5, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX(hbox2), bg_pixmap, TRUE, TRUE, 0);

  browse_button = gtk_button_new_with_label ("Browse...");

  gtk_box_pack_start (GTK_BOX(hbox2), browse_button, TRUE, TRUE, 30);

  gtk_box_pack_start (GTK_BOX(vbox4), label6, TRUE, TRUE, 0);

  gtk_signal_connect_object (GTK_OBJECT(use_pixmap), "toggled", GTK_SIGNAL_FUNC(property_changed), GTK_OBJECT(pbox));
    gtk_signal_connect_object (GTK_OBJECT(transparent), "toggled", GTK_SIGNAL_FUNC(property_changed), GTK_OBJECT(pbox));
  gtk_signal_connect_object (GTK_OBJECT(shaded), "toggled", GTK_SIGNAL_FUNC(property_changed), GTK_OBJECT(pbox));

  gtk_signal_connect_object (GTK_OBJECT(bg_pixmap), "changed", GTK_SIGNAL_FUNC(property_changed), GTK_OBJECT(pbox));



  gtk_signal_connect_object (GTK_OBJECT(browse_button), "clicked",
			     GTK_SIGNAL_FUNC (browse_clicked), GTK_OBJECT(pbox));

}

/*
int DoPreferences()
{

  GtkWidget * cancel, * ok;
  GtkWidget * button_box;

  dialog = gtk_dialog_new();

  cancel = gtk_button_new_with_label ("Cancel");
  ok = gtk_button_new_with_label ("Ok");

  button_box = gtk_hbox_new (TRUE, 10);
  gtk_box_pack_start (GTK_BOX (button_box), ok, TRUE, TRUE, 0);
  gtk_box_pack_start (GTK_BOX (button_box), cancel, TRUE, TRUE, 0);

  gtk_signal_connect_object (GTK_OBJECT(cancel), "clicked",
			     GTK_SIGNAL_FUNC (cancel_clicked), GTK_OBJECT(dialog));

  gtk_signal_connect_object (GTK_OBJECT(ok), "clicked",
			     GTK_SIGNAL_FUNC (ok_clicked), GTK_OBJECT(dialog));

  gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->action_area), button_box);

  gtk_window_set_title (GTK_WINDOW(dialog), "Preferences");
  
  CreatePrefs (GTK_CONTAINER(GTK_DIALOG(dialog)->vbox));

  /*  gtk_window_set_modal (GTK_WINDOW(dialog), 1);
  gtk_widget_show_all (dialog);

}

*/
